==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "客户"

, "State"
: "情形"

, "Role"
: "职务"

, "Source"
: "源"

, "Start"
: "开始"

, "Scheduled end"
: "预订结束"

, "End"
: "结束"

, "Turnover"
: "周转"

, "Probability"
: "可能性"

, "Folder"
: "文件夹"

, "Updated by"
: "更新者"

, "Updated Fields:"
: "更新的字段："

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: ""

, "Lead %s has been changed"
: "线索 %s 已经被更新"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "潜在客户 %s 已被创建"

, "Lead Data"
: "线索数据"

, "Leadstate"
: "线索状态"

, "Leadtype"
: "线索类型"

, "Leadsource"
: "线索源"

, "End Scheduled"
: "预计的结束"

, "Contacts"
: "联系人"

, "Address"
: "地址"

, "Telephone"
: "电话"

, "Email"
: "电子邮件"

, "Tasks"
: "任务"

, "Due Date"
: "过期日期"

, "Priority"
: "优先"

, "Products"
: "产品"

, "low"
: "低"

, "normal"
: "正常"

, "high"
: "高"

, "urgent"
: "紧急"

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification Emails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications Emails for own actions"
: ""

, "Get notifications emails for actions you did yourself"
: ""

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "manage shared lead folders"
: "管理潜在客户共享资料夹"

, "Create new shared lead folders"
: "创建潜在客户共享资料夹"

, "manage shared leads favorites"
: "管理潜在客户共享收藏夹"

, "Create or update shared leads favorites"
: "创建或更新潜在客户共享收藏夹"

, "Contact"
: ""

, "CRM Role"
: ""

, "Lead, Leads"
: [
  ""

]
, "lead list, lead lists"
: [
  ""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Lead name"
: "线索名"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Estimated end"
: "估计结束"

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "伙伴"

, "Phone"
: "电话"

, "Mobile"
: ""

, "Fax"
: ""

, "E-Mail"
: ""

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "状态"

, "Change type to Customer"
: "修改客户类型"

, "Responsible"
: "负责人"

, "Change type to Responsible"
: "修改负责人类型"

, "Change type to Partner"
: "修改伙伴类型"

, "Change contact type"
: "修改联系人类型"

, "Search for Contacts to add ..."
: "搜索联系人添加到 ..."

, "Name"
: "姓名"

, "Data"
: ""

, "Cellphone"
: "手机"

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: ""

, "Edit selected {0}"
: ""

, "No Tasks to display"
: "没有任务要显示"

, "Summary"
: "摘要"

, "Add a task..."
: "添加任务..."

, "Percent"
: "百分比"

, "Organizer"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Probable Turnover"
: ""

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: "期望的周转"

, "Description"
: "描述"

, "Enter description"
: "输入描述"

, "New Lead"
: ""

, "Product"
: ""

, "Price"
: "价格"

, "Quantity"
: ""

, "Search for Products to add ..."
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "打开"

, "contacted"
: "联系过的"

, "waiting for feedback"
: "等待反馈"

, "quote sent"
: "报价已发送"

, "accepted"
: "已接受"

, "lost"
: "失去"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "代理商"

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Crm/js/Crm-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "New Lead"
: ""

, "Tags"
: ""

, "Lead name"
: "线索名"

, "Responsible"
: "负责人"

, "Partner"
: "伙伴"

, "Customer"
: "客户"

, "Leadstate"
: "线索状态"

, "Leadtype"
: "线索类型"

, "Leadsource"
: "线索源"

, "Probability"
: "可能性"

, "Turnover"
: "周转"

, "Estimated end"
: "估计结束"

, "Probable Turnover"
: ""

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: ""

, "CRM Role"
: ""

, "Tasks"
: "任务"

, "No Tasks to display"
: "没有任务要显示"

, "Summary"
: "摘要"

, "Add a task..."
: "添加任务..."

, "Due Date"
: "过期日期"

, "Priority"
: "优先"

, "Percent"
: "百分比"

, "Status"
: "状态"

, "Organizer"
: ""

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: ""

, "Edit selected {0}"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  ""

]
, "Select Lead"
: ""

, "Role"
: "职务"

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Phone"
: "电话"

, "Mobile"
: ""

, "Fax"
: ""

, "E-Mail"
: ""

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "开始"

, "Change type to Customer"
: "修改客户类型"

, "Change type to Responsible"
: "修改负责人类型"

, "Change type to Partner"
: "修改伙伴类型"

, "Change contact type"
: "修改联系人类型"

, "Search for Contacts to add ..."
: "搜索联系人添加到 ..."

, "Name"
: "姓名"

, "Address"
: "地址"

, "Data"
: ""

, "Cellphone"
: "手机"

, "End"
: "结束"

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "Products"
: "产品"

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: "期望的周转"

, "Description"
: "描述"

, "Enter description"
: "输入描述"

, "lead list, lead lists"
: [
  ""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: ""

, "Price"
: "价格"

, "Quantity"
: ""

, "Search for Products to add ..."
: ""

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "打开"

, "contacted"
: "联系过的"

, "waiting for feedback"
: "等待反馈"

, "quote sent"
: "报价已发送"

, "accepted"
: "已接受"

, "lost"
: "失去"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "代理商"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "情形"

, "Source"
: "源"

, "Scheduled end"
: "预订结束"

, "Folder"
: "文件夹"

, "Updated by"
: "更新者"

, "Updated Fields:"
: "更新的字段："

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "线索 %s 已经被更新"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "潜在客户 %s 已被创建"

, "Task"
: ""

, "Lead Data"
: "线索数据"

, "End Scheduled"
: "预计的结束"

, "Contacts"
: "联系人"

, "Telephone"
: "电话"

, "Email"
: "电子邮件"

, "low"
: "低"

, "normal"
: "正常"

, "high"
: "高"

, "urgent"
: "紧急"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "管理潜在客户共享资料夹"

, "Create new shared lead folders"
: "创建潜在客户共享资料夹"

, "manage shared leads favorites"
: "管理潜在客户共享收藏夹"

, "Create or update shared leads favorites"
: "创建或更新潜在客户共享收藏夹"

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
